@@ -28,6 +28,7 @@
 JNIEnv *jni_get_env(const char *name);
 
 static const libvlc_event_type_t mp_events[] = {
+    libvlc_MediaPlayerMediaChanged,
     libvlc_MediaPlayerOpening,
     libvlc_MediaPlayerPlaying,
     libvlc_MediaPlayerPaused,
@@ -290,7 +291,7 @@ Java_org_videolan_libvlc_MediaPlayer_pause(JNIEnv *env, jobject thiz)
     if (!p_obj)
         return;
 
-    libvlc_media_player_pause(p_obj->u.p_mp);
+    libvlc_media_player_set_pause(p_obj->u.p_mp, 1);
 }
 
 jint
