@@ -60,6 +60,7 @@ struct fields {
         jmethodID createAudioTrackFromNativeID;
         jmethodID createVideoTrackFromNativeID;
         jmethodID createSubtitleTrackFromNativeID;
+        jmethodID createUnknownTrackFromNativeID;
     } Media;
     struct {
         struct {
@@ -81,6 +82,22 @@ struct fields {
         jmethodID createChapterFromNativeID;
         jmethodID createTrackDescriptionFromNativeID;
     } MediaPlayer;
+    struct {
+        struct {
+            jclass clazz;
+        } Description;
+        jclass clazz;
+        jmethodID createDescriptionFromNativeID;
+    } MediaDiscoverer;
+    struct {
+        jclass clazz;
+        jmethodID displayErrorFromNativeID;
+        jmethodID displayLoginFromNativeID;
+        jmethodID displayQuestionFromNativeID;
+        jmethodID displayProgressFromNativeID;
+        jmethodID cancelFromNativeID;
+        jmethodID updateProgressFromNativeID;
+    } Dialog;
 };
 
 extern struct fields fields;
